==> helm-annotations-2.11.5-sources.jar: io/dekorate/helm/config/HelmDependency.java <==
package io.dekorate.helm.config;

import java.lang.Object;
import java.lang.String;
import io.sundr.builder.annotations.Buildable;

 /**
  * Generated
  */
  @Buildable(builderPackage = "io.fabric8.kubernetes.api.builder")
  public class HelmDependency{
  public HelmDependency() {
  }
  public HelmDependency(String name,java.lang.String alias,java.lang.String version,java.lang.String repository,java.lang.String condition,java.lang.String[] tags) {
    this.name = name;
    this.alias = alias;
    this.version = version;
    this.repository = repository;
    this.condition = condition;
    this.tags = tags != null ? tags : new java.lang.String[0];
  }
  private java.lang.String name;
  private java.lang.String alias;
  private java.lang.String version;
  private java.lang.String repository;
  private java.lang.String condition;
  private java.lang.String[] tags = new java.lang.String[0];
  public java.lang.String getName() {
    return this.name;
  }
  public java.lang.String getAlias() {
    return this.alias;
  }
  public java.lang.String getVersion() {
    return this.version;
  }
  public java.lang.String getRepository() {
    return this.repository;
  }
  public java.lang.String getCondition() {
    return this.condition;
  }
  public java.lang.String[] getTags() {
    return this.tags;
  }
  public static HelmDependencyBuilder newBuilder() {
    return new HelmDependencyBuilder();
  }
  public static io.dekorate.helm.config.HelmDependencyBuilder newBuilderFromDefaults() {
    return new io.dekorate.helm.config.HelmDependencyBuilder();
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HelmDependency that = (HelmDependency) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (alias != null ? !alias.equals(that.alias) :that.alias != null) return false;
    if (version != null ? !version.equals(that.version) :that.version != null) return false;
    if (repository != null ? !repository.equals(that.repository) :that.repository != null) return false;
    if (condition != null ? !condition.equals(that.condition) :that.condition != null) return false;
    if (tags != null ? !tags.equals(that.tags) :that.tags != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  alias,  version,  repository,  condition,  tags,  super.hashCode());
  }
  
}

==> helm-annotations-3.0.2-sources.jar: io/dekorate/helm/config/HelmDependency.java <==
package io.dekorate.helm.config;

import java.lang.Object;
import java.lang.String;
import io.sundr.builder.annotations.Buildable;

 /**
  * Generated
  */
  @Buildable(builderPackage = "io.fabric8.kubernetes.api.builder")
  public class HelmDependency{
  public HelmDependency() {
  }
  public HelmDependency(String name,String alias,String version,String repository,String condition,String[] tags) {
    this.name = name;
    this.alias = alias;
    this.version = version;
    this.repository = repository;
    this.condition = condition;
    this.tags = tags != null ? tags : new String[0];
  }
  private String name;
  private String alias;
  private String version;
  private String repository;
  private String condition;
  private String[] tags = new String[0];
  public String getName() {
    return this.name;
  }
  public String getAlias() {
    return this.alias;
  }
  public String getVersion() {
    return this.version;
  }
  public String getRepository() {
    return this.repository;
  }
  public String getCondition() {
    return this.condition;
  }
  public String[] getTags() {
    return this.tags;
  }
  public static HelmDependencyBuilder newBuilder() {
    return new HelmDependencyBuilder();
  }
  public static HelmDependencyBuilder newBuilderFromDefaults() {
    return new HelmDependencyBuilder();
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HelmDependency that = (HelmDependency) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (alias != null ? !alias.equals(that.alias) :that.alias != null) return false;
    if (version != null ? !version.equals(that.version) :that.version != null) return false;
    if (repository != null ? !repository.equals(that.repository) :that.repository != null) return false;
    if (condition != null ? !condition.equals(that.condition) :that.condition != null) return false;
    if (tags != null ? !tags.equals(that.tags) :that.tags != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  alias,  version,  repository,  condition,  tags,  super.hashCode());
  }
  
}
